commit a3836d990926dfd8e7e35b266274c372c72206ce
Author: Juergen Spitzmueller <sp...@lyx.org>
Date:   Sun Mar 11 11:12:42 2018 +0100

    tex2lyx: support for URW Classico, MinionPro and the new Libertine fonts.
---
 src/tex2lyx/Preamble.cpp |   39 +++++++++++++++++++++++++++------------
 src/tex2lyx/TODO.txt     |    4 ----
 2 files changed, 27 insertions(+), 16 deletions(-)

diff --git a/src/tex2lyx/TODO.txt b/src/tex2lyx/TODO.txt
index 9e99848..522c0ec 100644
--- a/src/tex2lyx/TODO.txt
+++ b/src/tex2lyx/TODO.txt
@@ -51,11 +51,7 @@ Format LaTeX feature                        LyX feature
 411    support for polyglossia              \language_package  (the cases of 
no package, of babel and of custom package is supported)
 415    automatic undertilde loading         \use_package undertilde
 438    \t*{ }                               InsetTIPA
-439    MinionPro.sty                        \font_roman, \font_osf
-440    MinionPro.sty,                       \font_math
 443    unicode-math.sty                     InsetMath*
-445    URW Classico LaTeX font              \font_sans uop
-       \renewcommand{\sffamily}{uop}
 448
 451    beamer overlay arguments             InsetArgument
        \command<arg>, \begin{env}<arg>

Reply via email to
diff --git a/src/tex2lyx/Preamble.cpp b/src/tex2lyx/Preamble.cpp
index 7086897..0101014 100644
--- a/src/tex2lyx/Preamble.cpp
+++ b/src/tex2lyx/Preamble.cpp
@@ -126,17 +126,17 @@ char const * const known_fontsizes[] = { "10pt", "11pt", 
"12pt", 0 };
 
 const char * const known_roman_fonts[] = { "ae", "beraserif", "bookman",
 "ccfonts", "chancery", "charter", "cmr", "cochineal", "crimson", "fourier",
-"garamondx", "libertine", "libertine-type1", "lmodern", "mathdesign", 
"mathpazo",
-"mathptmx", "newcent", "NotoSerif-TLF", "PTSerif-TLF", "tgbonum", "tgchorus",
+"garamondx", "libertine", "libertineRoman", "libertine-type1", "lmodern", 
"mathdesign", "mathpazo",
+"mathptmx", "MinionPro", "newcent", "NotoSerif-TLF", "PTSerif-TLF", "tgbonum", 
"tgchorus",
 "tgpagella", "tgschola", "tgtermes", "utopia", 0 };
 
-const char * const known_sans_fonts[] = { "avant", "berasans", 
"biolinum-type1",
-"cmbr", "cmss", "helvet", "iwona", "iwonac", "iwonal", "iwonalc", "kurier",
-"kurierc", "kurierl", "kurierlc", "lmss", "NotoSans-TLF", "PTSans-TLF", 
"tgadventor",
-"tgheros", 0 };
+const char * const known_sans_fonts[] = { "avant", "berasans", "biolinum",
+"biolinum-type1", "cmbr", "cmss", "helvet", "iwona", "iwonac", "iwonal", 
"iwonalc",
+"kurier", "kurierc", "kurierl", "kurierlc", "lmss", "NotoSans-TLF", 
"PTSans-TLF",
+"tgadventor", "tgheros", "uop", 0 };
 
 const char * const known_typewriter_fonts[] = { "beramono", "cmtl", "cmtt",
-"courier", "lmtt", "luximono", "fourier", "libertineMono-type1", "lmodern",
+"courier", "lmtt", "luximono", "fourier", "libertineMono", 
"libertineMono-type1", "lmodern",
 "mathpazo", "mathptmx", "newcent", "NotoMono-TLF", "PTMono-TLF", "tgcursor", 
"txtt", 0 };
 
 const char * const known_math_fonts[] = { "eulervm", "newtxmath", 0};
@@ -734,22 +734,37 @@ void Preamble::handle_package(Parser &p, string const & 
name,
                h_font_roman[0] = "libertine";
                // this automatically invokes biolinum
                h_font_sans[0] = "biolinum";
+               // as well as libertineMono
+               h_font_typewriter[0] = "libertine-mono";
                if (opts == "osf")
                        h_font_osf = "true";
                else if (opts == "lining")
                        h_font_osf = "false";
        }
 
-       if (name == "libertine-type1") {
+       if (name == "libertineRoman" || name == "libertine-type1") {
                h_font_roman[0] = "libertine";
                // NOTE: contrary to libertine.sty, libertine-type1
                // does not automatically invoke biolinum
                if (opts == "lining")
                        h_font_osf = "false";
                else if (opts == "osf")
                        h_font_osf = "true";
        }
 
+       if (name == "MinionPro") {
+               h_font_roman[0] = "minionpro";
+               if (opts.find("lf") != string::npos)
+                       h_font_osf = "false";
+               else
+                       h_font_osf = "true";
+               if (opts.find("onlytext") != string::npos)
+                       h_font_math[0] = "default";
+               else
+                       h_font_math[0] = "auto";
+       }
+
        if (name == "mathdesign") {
                if (opts.find("charter") != string::npos)
                        h_font_roman[0] = "md-charter";
@@ -818,7 +833,7 @@ void Preamble::handle_package(Parser &p, string const & 
name,
                }
        }
 
-       if (name == "biolinum-type1") {
+       if (name == "biolinum" || name == "biolinum-type1") {
                h_font_sans[0] = "biolinum";
                // biolinum can have several options, e.g. [osf,scaled=0.97]
                string::size_type pos = opts.find("osf");
@@ -847,7 +862,7 @@ void Preamble::handle_package(Parser &p, string const & 
name,
                }
        }
 
-       if (name == "libertineMono-type1")
+       if (name == "libertineMono" || name == "libertineMono-type1")
                h_font_typewriter[0] = "libertine-mono";
 
        if (name == "PTMono") {
@@ -734,22 +734,37 @@ void Preamble::handle_package(Parser &p, string const & 
                h_font_roman[0] = "libertine";
-               // NOTE: contrary to libertine.sty, libertine-type1
-               // does not automatically invoke biolinum
+               // NOTE: contrary to libertine.sty, libertineRoman
+               // and libertine-type1 do not automatically invoke
+               // biolinum and libertineMono
                if (opts == "lining")
                        h_font_osf = "false";